==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCardContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardContentDescription } from "./WebCardContentDescription";
/**
 * @hidden
 */
var WebCardContentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardContentDescriptionMetadata, _super);
    function WebCardContentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardContentDescriptionMetadata.b = function (a) {
        if (WebCardContentDescriptionMetadata.a == null) {
            WebCardContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardContentDescriptionMetadata.c(WebCardContentDescriptionMetadata.a);
        }
        if (a.j(WebCardContentDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCardContentDescriptionMetadata.a);
    };
    WebCardContentDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardContent");
        a.item("__tagNameWC", "String:igc-card-content");
    };
    WebCardContentDescriptionMetadata.d = function (a) {
        WebCardContentDescriptionMetadata.b(a);
        a.aa("WebCardContent", function () { return new WebCardContentDescription(); });
        a.z("WebCardContent", WebCardContentDescriptionMetadata.a);
    };
    WebCardContentDescriptionMetadata.$t = markType(WebCardContentDescriptionMetadata, 'WebCardContentDescriptionMetadata');
    WebCardContentDescriptionMetadata.a = null;
    return WebCardContentDescriptionMetadata;
}(Base));
export { WebCardContentDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebCardContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardContentDescription } from "./WebCardContentDescription";
/**
 * @hidden
 */
var WebCardContentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardContentDescriptionMetadata, _super);
    function WebCardContentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardContentDescriptionMetadata.b = function (a) {
        if (WebCardContentDescriptionMetadata.a == null) {
            WebCardContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardContentDescriptionMetadata.c(WebCardContentDescriptionMetadata.a);
        }
        if (a.k(WebCardContentDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebCardContentDescriptionMetadata.a);
    };
    WebCardContentDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardContent");
        a.item("__tagNameWC", "String:igc-card-content");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebCardContentDescriptionMetadata.d = function (a) {
        WebCardContentDescriptionMetadata.b(a);
        a.ac("WebCardContent", function () { return new WebCardContentDescription(); });
        a.ab("WebCardContent", WebCardContentDescriptionMetadata.a);
    };
    WebCardContentDescriptionMetadata.$t = markType(WebCardContentDescriptionMetadata, 'WebCardContentDescriptionMetadata');
    WebCardContentDescriptionMetadata.a = null;
    return WebCardContentDescriptionMetadata;
}(Base));
export { WebCardContentDescriptionMetadata };
